<?php

add_action( 'after_setup_theme', 'mariah_i18n' );
/**
 * Load the child theme textdomain for internationalization.
 *
 * Must be loaded before Genesis Framework /lib/init.php is included.
 * Translations can be filed in the /languages/ directory.
 *
 * @since 1.2.0
 */
function mariah_i18n() {
    load_child_theme_textdomain( 'mariah', get_stylesheet_directory() . '/languages' );
}

add_action( 'wp_enqueue_scripts', 'wsm_enqueue_assets' );
/**
 * Enqueue theme assets.
 */
function wsm_enqueue_assets() {
	wp_enqueue_style( 'mariah', get_stylesheet_uri() );
	wp_style_add_data( 'mariah', 'rtl', 'replace' );
}

/** Start the engine */
require_once( get_template_directory() . '/lib/init.php' );
require_once( 'lib/init.php' );

// Calls the theme's constants & files
mariah_init();

// Create additional color style options
add_theme_support( 'genesis-style-selector',
	array(
		'mariah-green-purple' => __( 'Green/Purple', 'mariah' ),
		'mariah-blue' => __( 'Blue', 'mariah' ),
		'mariah-red-tan' => __( 'Red/Tan', 'mariah' ),
		'mariah-green-charcoal' => __( 'Green/Charcoal', 'mariah' ),
		'mariah-red-green-beige' => __( 'Beige/Green/Red', 'mariah' ),
	)
);

/** Add Viewport meta tag for mobile browsers */
add_action( 'genesis_meta', 'add_viewport_meta_tag' );
function add_viewport_meta_tag() {
    echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>';
}

// Force Stupid IE to NOT use compatibility mode
add_filter( 'wp_headers', 'wsm_keep_ie_modern' );
function wsm_keep_ie_modern( $headers ) {
        if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE' ) !== false ) ) {
                $headers['X-UA-Compatible'] = 'IE=edge,chrome=1';
        }
        return $headers;
}

// Load Moderinzr script for IE and Gravity Forms placeholders
add_action( 'wp_enqueue_scripts', 'wsm_load_modernizr' );
function wsm_load_modernizr() {
	wp_enqueue_script( 'jquery' );
	wp_register_script( 'modernizr', CHILD_URL . '/lib/js/modernizr.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'modernizr' );
}

// Add new image sizes
add_image_size( 'Blog Thumbnail', 150, 150, TRUE );

// Customize search form input button text
add_filter( 'genesis_search_button_text', 'custom_search_button_text' );
function custom_search_button_text( $text ) {
    return esc_attr( __( 'Go', 'mariah' ) );
}

// Modify Post Info
add_filter( 'genesis_post_info', 'mariah_post_info' );
function mariah_post_info( $post_info ) {
	if ( !is_page() ) {
		$post_info = '[post_date format="d. m. y" label="' . __( 'Posted On:', 'mariah' ) . '"] ';
	}
	return $post_info;
}

// Customize the post meta function
add_filter( 'genesis_post_meta', 'mariah_post_meta' );
function mariah_post_meta( $post_meta ) {

	if ( is_single() ) {
    	$post_meta = '[post_categories sep=", " before="<strong>' .  __( 'Categories:', 'mariah' ) . '</strong> "] [post_tags sep=", " before="<strong>' .  __( 'Tags:', 'mariah' ) . '</strong> "]';
    	return $post_meta;
	}

	else {
    	remove_action( 'genesis_entry_footer', 'genesis_post_meta' );
	}

}

// Modify the length of post excerpts
add_filter( 'excerpt_length', 'custom_excerpt_length' );
function custom_excerpt_length( $length ) {
    return 32; // pull first 32 words
}

// Customize the Author Box
add_filter( 'genesis_author_box', 'mariah_author_box' );
function mariah_author_box( $pattern ) {
	global $authordata;
	global $context;

	$authordata    = is_object( $authordata ) ? $authordata : get_userdata( get_query_var( 'author' ) );
	$gravatar_size = apply_filters( 'genesis_author_box_gravatar_size', 110, $context );
	$gravatar      = get_avatar( get_the_author_meta( 'email' ), $gravatar_size );
	$description   = wpautop( get_the_author_meta( 'description' ) );

	$pattern  = sprintf( '<section %s>', genesis_attr( 'author-box' ) );
	$pattern .= $gravatar;
	$pattern .= sprintf( '<strong class="author-box-title">' .  __( 'About', 'mariah' ) . ' %s</strong>', get_the_author_meta( 'display_name' ) );
	$pattern .= sprintf( '<p class="author-box-content" itemprop="description">%s</p>', $description );
	$pattern .= '</section>';

	return $pattern;
}

// Custom Read More link
add_filter( 'excerpt_more', 'child_read_more_link' );
add_filter( 'the_content_more_link', 'child_read_more_link' );
function child_read_more_link() {
	return ' <a class="more-link" href="' . get_permalink() . '" rel="nofollow">' .  __( '[Continue Reading]', 'mariah' ) . '</a>';
}

// Reposition the featured image
remove_action( 'genesis_entry_content', 'genesis_do_post_image', 8 );
add_action( 'genesis_entry_header', 'genesis_do_post_image', 5 ) ;

// Structural Wrap
add_theme_support( 'genesis-structural-wraps', array( 'header', 'nav', 'subnav', 'inner','footer-widgets', 'footer' ) );

// Setup Sidebars
genesis_register_sidebar( array(
	'id'			=> 'home-slider',
	'name'			=> __( 'Home Slider', 'mariah' ),
	'description'	=> __( 'This is Home page image slider area. Drag the Soliloquy widget here.', 'mariah' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-top-left',
	'name'			=> __( 'Home Top Left', 'mariah' ),
	'description'	=> __( 'This is the Top area on the Home Page to the Left of the image slider.', 'mariah' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta-01',
	'name'			=> __( 'Home Call to Action Box 01', 'mariah' ),
	'description'	=> __( 'This is the Call to Action area to the left of the image rotator.', 'mariah' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta-02',
	'name'			=> __( 'Home Call to Action Box 02', 'mariah' ),
	'description'	=> __( 'This is the Bottom Left widget area on the Home page.', 'mariah' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta-03',
	'name'			=> __( 'Home Call to Action Box 03', 'mariah' ),
	'description'	=> __( 'This is the Bottom Center widget area on the Home page.', 'mariah' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta-04',
	'name'			=> __( 'Home Call to Action Box 04', 'mariah' ),
	'description'	=> __( 'This is the Bottom Right widget area on the Home page.', 'mariah' ),
) );


genesis_register_sidebar( array(
	'id'			=> 'blog-sidebar',
	'name'			=> __( 'Blog Sidebar', 'mariah' ),
	'description'	=> __( 'This is the Blog Sidebar.', 'mariah' ),
) );


genesis_register_sidebar( array(
	'id'			=> 'page-sidebar',
	'name'			=> __( 'Page Sidebar', 'mariah' ),
	'description'	=> __( 'This is the Page Sidebar.', 'mariah' ),
) );

// Add Home  link before main nav
add_filter( 'genesis_nav_items', 'wsm_home_link', 10, 2 );
add_filter( 'wp_nav_menu_items', 'wsm_home_link', 10, 2 );
function wsm_home_link( $menu, $args ) {
	$args = (array)$args;
	if ( 'primary' !== $args['theme_location']  )
	return $menu;
	$homelink = '<li id="home-link"><a class="home-button" href="'.home_url('/').'">' .  __( 'Home', 'mariah' ) . '</a></li>';
	return $homelink . $menu;
}

// Change number of WooCommerce products per row to 3
add_filter( 'loop_shop_columns', 'wsm_loop_shop_columns', 1, 10 );
function wsm_loop_shop_columns( $number_columns ) {
	return 3;
}
