<?php         

/**
 * Mariah Settings
 * Requires Genesis 1.8 or later
 *
 * This file registers all of this child theme's 
 * specific Theme Settings, accessible from
 * Genesis > Portfolio Settings.
 *
 * @category     Mariah
 * @package      Admin
 * @author       Web Savvy Marketing
 * @copyright    Copyright (c) 2012, Web Savvy Marketing
 * @license      http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since        1.0.0
 *
 */
 
/**
 * Registers a new admin page, providing content and corresponding menu item
 * for the Child Theme Settings page.
 *
 * @category     minFolio
 * @package      Admin
 * @since        1.0.0
 */
class Mariah_Settings extends Genesis_Admin_Boxes {
	
	/**
	 * Create an admin menu item and settings page.
	 * 
	 * @since 1.0.0
	 */
	function __construct() {
		
		// Specify a unique page ID. 
		$page_id = 'mariah';
		
		// Set it as a child to genesis, and define the menu and page titles
		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title'  => __( 'Mariah Settings', 'mariah' ),
				'menu_title'  => __( 'Mariah Settings', 'mariah' ),
				'capability'  => 'manage_options',
			)
		);
		
		// Set up page options. These are optional, so only uncomment if you want to change the defaults
		$page_ops = array( 'screen_icon' => 'options-general', );		
		
		// Give it a unique settings field. 
		// You'll access them from genesis_get_option( 'option_name', 'mariah-settings' );
		$settings_field = 'mariah-settings';
		
		// Set the default values
		$default_settings = array(
			'mariah_copyright' => 'Copyright © 2014 Web Savvy Marketing  • All Rights Reserved',
			'mariah_credit' => 'Mariah is a Genesis Child Theme Designed by Web Savvy Marketing',
			'wsm_ignore_updates' => 0,
			'wsm_gforms_placeholder' => 1,
			'wsm_presstrends_opt' => 1,
		);
		
		// Create the Admin Page
		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		// Initialize the Sanitization Filter
		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitization_filters' ) );
	}

	/** 
	 * Set up Sanitization Filters
	 *
	 * See /lib/classes/sanitization.php for all available filters.
	 *
	 * @since 1.0.0
	 */	
	function sanitization_filters() {
		
		genesis_add_option_filter(
			'safe_html',
			$this->settings_field,
			array(
				'mariah_copyright',
				'mariah_credit',
			)
		);
	}
	
	/**
	 * Register metaboxes on Child Theme Settings page
	 *
	 * @since 1.0.0
	 *
	 * @see Mariah_Settings::mariah_footer_metabox() Callback for child footer content settings
	 */
	function metaboxes() {
		
		add_meta_box( 'mariah-footer-box', __( 'Footer Content', 'mariah' ),  array( $this, 'mariah_footer_metabox' ), $this->pagehook, 'main', 'high' );
		add_meta_box('wsm_gforms_placeholders_metabox', __( 'Gravity Forms Auto Placeholders', 'mariah' ), array( $this, 'wsm_gforms_placeholders_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_upate_notifications_metabox', __( 'Update Notifications', 'mariah' ), array( $this, 'wsm_upate_notifications_metabox' ), $this->pagehook, 'main', 'high');
				
	}
	
	/**
	 * Callback for Mariah Footer Settings metabox
	 *
	 * @since 1.0.0
	 *
	 * @see Mariah_Settings::metaboxes()
	 */
	function mariah_footer_metabox() { 
		
		echo '<p><strong>' .  __( 'Copyright Text:', 'mariah' ) . '</strong><br/>';
		echo '<input type="text" name="' . $this->get_field_name( 'mariah_copyright' ) . '" id="' . $this->get_field_id( 'mariah_copyright' ) . '" value="' . esc_attr( $this->get_field_value( 'mariah_copyright' ) ) . '" size="70" /></p>';
		
		echo '<p><strong>' .  __( 'Credit Text:', 'mariah' ) . '</strong><br/>';
		echo '<input type="text" name="' . $this->get_field_name( 'mariah_credit' ) . '" id="' . $this->get_field_id( 'mariah_credit' ) . '" value="' . esc_attr( $this->get_field_value( 'mariah_credit' ) ) . '" size="70" /></p>';  
		 
	}
	
	/**
	 * Gravity Forms Auto Placeholders Metabox
	 * @since 2.0.0
	 */
	function wsm_gforms_placeholders_metabox() {

		echo '<input type="checkbox" name="' . $this->get_field_name( 'wsm_gforms_placeholder' ) . '" id="' .  $this->get_field_id( 'wsm_gforms_placeholder' ) . '" value="1"';
		checked( 1, $this->get_field_value( 'wsm_gforms_placeholder' ) ); echo '/>';
		
		echo '<label for="' . $this->get_field_id( 'wsm_gforms_placeholder' ) . '">' . __( 'Only convert labels to placeholders on forms or form items with the class <strong><em>gforms-placeholder</em></strong>', 'mariah' ) . '</label>';
		echo '<p><em>' . __( 'By default, leaving this unchecked will apply the effect to all Gravity Form fields.', 'mariah' ) . '</em></p>';
			
	}
	
	/**
	 * Update Notifications Metabox
	 * @since 2.0.0
	 */
	function wsm_upate_notifications_metabox() {

		echo '<p>' . __( 'Please check the box below if you wish to ignore/hide the theme update notification.<br/>Uncheck the box if you wish to be notified of theme updates.', 'mariah' ) . '</p>';
		
		echo '<input type="checkbox" name="' . $this->get_field_name( 'wsm_ignore_updates' ) . '" id="' .  $this->get_field_id( 'wsm_ignore_updates' ) . '" value="1" ';
		checked( 1, $this->get_field_value( 'wsm_ignore_updates' ) ); 
		echo '/> <label for="' . $this->get_field_id( 'wsm_ignore_updates' ) . '">' . __( 'Ignore Theme Updates?', 'mariah' ) . '</label>';
			
	}
	
}


/**
 * Add the Theme Settings Page
 *
 * @since 1.0.0
 */
function mariah_add_settings() {
	global $_mariah_settings;
	$_mariah_settings = new Mariah_Settings;	 	
}
add_action( 'admin_menu', 'mariah_add_settings', 5 );

/**
 * Add Soliloquy key
 *
 * @since 1.0.0
 */
// Soliloquy License
if ( ! get_option( 'soliloquy_license_key' ) )
	update_option( 'soliloquy_license_key', SOLILOQUY_LICENSE_KEY );